/****************************************************************************
 Module
   EventCheckers.c

 Revision
   1.0.1 

 Description
   This is the sample for writing event checkers along with the event 
   checkers used in the basic framework test harness.

 Notes
   Note the use of static variables in sample event checker to detect
   ONLY transitions.
   
 History
 When           Who     What/Why
 -------------- ---     --------
 08/06/13 13:36 jec     initial version
****************************************************************************/

// this will pull in the symbolic definitions for events, which we will want
// to post in response to detecting events
#include "ES_Configure.h"
// this will get us the structure definition for events, which we will need
// in order to post events in response to detecting events
#include "ES_Events.h"
// if you want to use distribution lists then you need those function 
// definitions too.
#include "ES_PostList.h"
// This include will pull in all of the headers from the service modules
// providing the prototypes for all of the post functions
#include "ES_ServiceHeaders.h"
// this test harness for the framework references the serial routines that
// are defined in ES_Port.c
#include "ES_Port.h"
// include our own prototypes to insure consistency between header & 
// actual functionsdefinition
#include "EventCheckers.h"

//Module Defines
#define RX_FLAG (PIR1 & BIT5HI) //mask off the RCIF flag, bit 5 in PIR1
#define RX_FLAG_HI BIT5HI

//#define TX_DISABLE_FLAG (PIE1 & BIT4HI) //mask off the TXIE flag, bit 4 in PIE1
//#define TX_DISABLE_FLAG_LO 0

#define	SS_LINE			( PORTC & BIT6HI )
#define	SS_LINE_HIGH	BIT6HI

/****************************************************************************
 Function
   Check4XbeeRX
 Parameters
   None
 Returns
   bool: true if a new event was detected
 Description
   Event checker to chect the RX flag on the SCI peripheral. This is used to 
   see if we recieve a new byte from the XBee
 Notes
   This may need to be replaced with an interrupt response routine, but for
   now I [NAM] think that is should work
 Author
   N. Martelaro, 05/11/14, 13:54
****************************************************************************/
bool Check4XBeeRX(void)
{
  static uint8_t LastFlagState = 0;
  uint8_t CurrentFlagState;
  bool ReturnVal = false;

  //PORTA ^= BIT0HI;	//toggle bit2 on port a as a RX event heartbeat
  //CurrentFlagState =  RX_FLAG; //check the recieve register full flag
  //UART_RX_DEBUG("RX Flag = %d \r\n", CurrentFlagState);
  // check for flag high AND different from last time
  // do the check for difference first so that you don't bother with a test
  // of a port/variable that is not going to matter, since it hasn't changed
  if ( RX_FLAG )
  {                     // event detected, so post detected event
    ES_Event UARTEvent;
    UARTEvent.EventType = ES_XBEE_RX;
    UARTEvent.EventParam = RCREG;
    // this could be any of the service post function, ES_PostListx or 
    // ES_PostAll functions
    PostPICUartRxFSM(UARTEvent);
	//PORTA ^= BIT0HI;	//toggle bit2 on port a as a RX event heartbeat 
    ReturnVal = true;
  }
  //LastFlagState = CurrentFlagState; // update the state for next time

  return ReturnVal;
}

/****************************************************************************
 Function
   Check4OverrunError
 Parameters
   None
 Returns
   bool: true if a new event was detected
 Description
   Event checker to chect the RX flag on the SCI peripheral. This is used to 
   see if we recieve a new byte from the XBee
 Notes
   This may need to be replaced with an interrupt response routine, but for
   now I [NAM] think that is should work
 Author
   N. Martelaro, 05/11/14, 13:54
****************************************************************************/
bool Check4OverrunError(void)
{
  bool ReturnVal = false;
  // if OERR bit is set
  //	PORTA ^= BIT0HI;
  if ( RCSTA & BIT1HI )
  {                     // event detected, so post detected event
    CREN = 0; // clear overrun flag
	PORTA ^= BIT0HI;	//toggle bit2 on port a as a RX event heartbeat 
	CREN = 1; // 
	ReturnVal = true;
  }

  return ReturnVal;
}

/****************************************************************************
 Function
   Check4TxDisable(void)
 Parameters
   None
 Returns
   bool: true if a new event was detected
 Description
   Event checker to chect the TX disable flag on the UART peripheral. Posts a
   ES_TX_DISABLE event to the PICUarTxFSM to stop it from transmitting.
 Notes
   This may need to be replaced with an interrupt response routine, but for
   now I [NAM] think that is should work
 Author
   N. Martelaro, 05/11/14, 13:54
****************************************************************************/
unsigned char SoftwareTXFlag = 0;

bool Check4TxDisable(void)
{
  bool ReturnVal = false;

  //UART_RX_DEBUG("RX Flag = %d \r\n", CurrentFlagState);
  // check for software TX flag high (set in interrupt)
  if ( SoftwareTXFlag )
  {                     // event detected, so post detected event
    ES_Event UARTEvent;
    UARTEvent.EventType = ES_TX_DISABLE;
    UARTEvent.EventParam = 1;
    // this could be any of the service post function, ES_PostListx or 
    // ES_PostAll functions
    PostPICUartTxFSM(UARTEvent);
	//PORTA ^= BIT2HI;	//toggle bit2 on port a as a TX event heartbeat 
    SoftwareTXFlag = 0;
	ReturnVal = true;
  }

  return ReturnVal;
}

/*
bool Check4TxDisable(void)
{
  static uint8_t LastFlagState = 0;
  uint8_t CurrentFlagState;
  bool ReturnVal = false;

  CurrentFlagState =  TX_DISABLE_FLAG; //check the recieve register full flag
  //UART_RX_DEBUG("RX Flag = %d \r\n", CurrentFlagState);
  // check for flag high AND different from last time
  // do the check for difference first so that you don't bother with a test
  // of a port/variable that is not going to matter, since it hasn't changed
  if ( (CurrentFlagState != LastFlagState) &&
       (CurrentFlagState == TX_DISABLE_FLAG_LO) )
  {                     // event detected, so post detected event
    ES_Event UARTEvent;
    UARTEvent.EventType = ES_TX_DISABLE;
    UARTEvent.EventParam = 1;
    // this could be any of the service post function, ES_PostListx or 
    // ES_PostAll functions
    PostPICUartTxFSM(UARTEvent);
	//PORTA ^= BIT2HI;	//toggle bit2 on port a as a TX event heartbeat 
    ReturnVal = true;
  }
  LastFlagState = CurrentFlagState; // update the state for next time

  return ReturnVal;
}
*/

/****************************************************************************
 Function
   Check4SPIFlag
 Parameters
   None
 Returns
   bool: true if a new event was detected
 Description
   Checks if SSPIF is set. If so, clears the flag, reads the new byte, loads
   SSPBUF with the current status byte (which it fetches from the PIC SPI FSM),
   and posts a BYTE_RECEIVED event to the PIC SPI FSM.
 Notes
   will not compile, sample only
 Author
   Buddy Gardineer
****************************************************************************/
/*
bool Check4SPIFlag(void)
{
	bool ReturnVal = false;
	unsigned char NewByte;
	unsigned char StatusToSend;

	if (SSPIF)
	{
		SSPIF = 0;
		NewByte = SSPBUF;
		SSPBUF = GetCurrentStatus();

		ES_Event ThisEvent;
		ThisEvent.EventType = BYTE_RECEIVED;
		ThisEvent.EventParam = NewByte;
		PostPIC_SPI_FSM( ThisEvent );
		ReturnVal = true;
	}	
  return ReturnVal;
}
*/

/****************************************************************************
 Function
   Check4SlaveSelectHigh
 Parameters
   None
 Returns
   bool: true if a new event was detected
 Description
   Checks if Slave Select line changes state and is high.
   PIC_SPI_FSM if true.
 Notes
   will not compile, sample only
 Author
   Buddy Gardineer
****************************************************************************/
bool Check4SlaveSelectHigh(void)
{
	bool ReturnVal = false;
	static unsigned char LastSlaveSelectState = SS_LINE_HIGH;
	unsigned char CurrentSlaveSelectState;

	CurrentSlaveSelectState = SS_LINE; //check current status of Slave Select

	  if ( (CurrentSlaveSelectState != LastSlaveSelectState) &&
	       (CurrentSlaveSelectState == SS_LINE_HIGH) )
	  {                     // SS line changed state and is high
	    ES_Event ThisEvent;
	    ThisEvent.EventType = SLAVE_SELECT_HIGH;
	    PostPIC_SPI_FSM( ThisEvent );
	    ReturnVal = true;
	  }
	  LastSlaveSelectState = CurrentSlaveSelectState; // update the state for next time

  return ReturnVal;
}
