/****************************************************************************
 Module
 	SPI.c

 Revision
	1.0.0

 Description
	SPI Module for the COACH PIC16F690.
   
 Notes
 
 ME 218c -- Team 13: Enchantment Under the Sea
 Author: Buddy Gardineer 
****************************************************************************/
/*----------------------------- Include Files -----------------------------*/
#include "ES_CheckEvents.h"
#include <stdio.h>		
#include <htc.h>			 /* header to specify PIC */
#include "bitdefs.h"       /* generic bit defs (BIT0HI, BIT0LO,...) */
#include "Bin_Const.h"     /* macros to specify binary constants in C */					
#include "SPI.h"

/*----------------------------- Module Defines ----------------------------*/

/*----------------------------- Module Variables ----------------------------*/
static unsigned char RX_BYTE;

/*---------------------------- Module Functions ---------------------------*/


/****************************************************************************
 Function
 	InitSPI
 
 Description
 	Initializes the SPI Module for communication with the COACH C32.
 
 Inputs
 	None
 
 Returns
 	None
 
 Notes
 
 Author: Buddy Gardineer
 *****************************************************************************/
void InitSPI(void)
{
	// configure COACH PIC as a Slave

	// configure SPI pins
	//TRISC = 0xFF; //all input
	//TRISC = BIT7LO;
	TRISC &= BIT7LO; // SDO
	TRISC |= BIT6HI; // SS
	TRISB |= BIT6HI; // SCK
	TRISB |= BIT4HI; // SDI (may not be needed, but just in case...)

	SMP = 0; // must be clear in Slave mode
	CKE = 0; // 
	CKP = 1; // Mode 3
	SSPM0 = 0;
	SSPM1 = 0;
	SSPM2 = 1;
	SSPM3 = 0; // SS pin control enabled

	PEIE = 1; // enable peripheral interrupts
	SSPIE = 1; // enable SPI interrupts

	//PORTA = 0; // set toggle pin initially LO

	SSPEN = 1; // enable SPI
}

/****************************************************************************
 Function
 WriteByteSPI
 
 Description
 Writes a byte to the TX buffer.
 
 Inputs
 Unsigned char (one byte)
 
 Returns
 bool TRUE if byte was successfully loaded into TX buffer, FALSE otherwise
 
 Notes
 
 Author: Buddy Gardineer
 *****************************************************************************/
bool WriteByteSPI(unsigned char byte)
{
	bool returnVal = true;
	
	SSPBUF = byte;

    return returnVal;   
}